//-*-c++-*-
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "tulip/Types.h"
#include "tulip/Sizes.h"
#include "tulip/SuperGraph.h"
#include "tulip/SizesProxy.h"

Sizes::Sizes (const PropertyContext &context):Property<SizeType , SizeType>(context) {
  sizesProxy=(SizesProxy *)context.propertyProxy;
}

